@@ -102,7 +102,7 @@ class Map:
         if self.isMapUpdated == False:
             _LOGGER.debug("GetBase64Map begin")
 
-            resizeFactor = 10
+            resizeFactor = 1
             pixelWidth = 50
             offset = 400
 
@@ -171,7 +171,7 @@ class Map:
 
             _LOGGER.debug("GetBase64Map resize")
             # Resize * resizeFactor
-            im = im.resize((im.size[0]*resizeFactor, im.size[1]*resizeFactor), Image.NEAREST)
+            ##im = im.resize((im.size[0]*resizeFactor, im.size[1]*resizeFactor), Image.NEAREST)
 
             if self.draw_charger:
                 _LOGGER.debug("GetBase64Map draw robot")
